@@ -6,8 +6,10 @@
 import unittest
 
 from domonic.dom import *
+from domonic.html import *
 from domonic.javascript import *
 from domonic.webapi import *
+
 # from domonic.decorators import silence
 
 
@@ -100,21 +102,17 @@ class TestCase(unittest.TestCase):
         pass
 
     def test_xhr(self):
-        from domonic.html import form, input, button, br, hr, div
+        from domonic.html import br, button, div, form, hr, input
         from domonic.javascript import Global
-
         # def on_submit(event):
         #     event.preventDefault()
         #     alert("Form submitted")
-
         # def on_load(event):
         #     event.preventDefault()
         #     alert("Page loaded")
-
         # def on_error(event):
         #     event.preventDefault()
         #     alert("Page error")
-
         from domonic.webapi.xhr import FormData
 
         myform = form(action='/', method='post')
@@ -226,6 +224,10 @@ class TestCase(unittest.TestCase):
         print(str(result.nodes[0]))
         # wow. nice!
 
+        expression = evaluator.createExpression("//a[contains(@href, 'twitter')]")
+        result = expression.evaluate(page, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE)
+        print("NO UNDERSCORE", str(result.nodes[0]))
+
         expression = evaluator.createExpression('//*[last()][name()="a"]')
         result = expression.evaluate(page, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE)
         print(str(result.nodes[0]))
@@ -235,6 +237,20 @@ class TestCase(unittest.TestCase):
         result = expression.evaluate(page, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE)
         print(str(result.nodes[0]))
 
+        somepage = html(head(), 
+                        body(
+                            h1("some title"),
+                            p("some text"),
+                            div("some more text")
+                        )
+                    )
+
+        expression = evaluator.createExpression('//div/text()')
+        result = expression.evaluate(somepage, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE)
+        print(str(result.nodes[0]))
+
+
+
         '''
         TODO - unit tests for the following so i know what works
 
